@echo off & setlocal EnableDelayedExpansion & set "$numTokens=1343"

Rem/For  This is a base program that process a file via FOR /F command with up to $numTokens tokens
Rem/For  This program was created using MakeForTokens.bat application written by Antonio Perez Ayala

Rem/For  Step 0:
Rem/For    In order to use this program, you should have a data file with many tokens to process.
Rem/For    A simple data file with 305 tokens is created here, so the examples below works correctly.
( for /L %%i in (1,1,%$numTokens%) do set /P "={%%i}," ) < NUL > dataFile.txt

Rem/For  Step 1:
Rem/For    Define the series of auxiliary variables that will be used as FOR tokens.
Rem/For    The subroutine use the value of $numTokens variable as input.
call :DefineForTokens

Rem/For  Step 2: (optional, but recommended)
Rem/For    Define an auxiliary variable that will contain the desired tokens when it is %expanded%.
Rem/For    This variable is created from a string similar to the original FOR /F "tokens=x,y,m-n" one,
Rem/For    but that allows larger token numbers, ranges in descending order and increment greater than 1,
Rem/For    and it also returns the number of created tokens. See full description later.
Rem/For    In the example below this variable is called "tokens" and it contains these tokens/elements:
Rem/For    10 28 29 30 31 32 170 167 164 161, and "tokens.len" variable is also created with 10.
Rem/For    You may or may not enclose the tokens definition between quotes.
call :ExpandTokensString "tokens=10,28-32,170-161-3"
echo Definition:  tokens=10,28-32,170-161-3  created %tokens.len% tokens

Rem/For  Step 3: (optional)
Rem/For    Define the variable with the "delims" value that will be used in the nested FOR's.
Rem/For    This variable must be named "delims" and it contains *the definition* of
Rem/For    the same part of the FOR command, including the "delims=" word itself.
Rem/For    If you want no delims (default: TAB+space), delete "delims" variable: set "delims="
Rem/For    If you want "delims=", define: set "delims=delims="
set "delims=delims=,"

Rem/For  Step 4:
Rem/For    Create the macro that contain the nested FOR's. This step must be performed after both
Rem/For    FOR tokens and "delims" variables was defined and before enter to the main FOR /F command.
Rem/For    The subroutine use the value of $numTokens variable as input.
call :CreateNestedFors

Rem/For  Step 5:
Rem/For    This is the main FOR /F command that process the file,
Rem/For    there is one additional nested FOR /F command for each 31 tokens (or part).
Rem/For    You must include the right filename in the next line:
for /F "usebackq tokens=1-31* %delims%" %%%$1% in ("dataFile.txt") do %NestedFors% (

   Rem/For  Step 6:
   Rem/For    Process the tokens. To just show they, use the "tokens" variable defined above:
   echo Tokens: %tokens%

   Rem/For    You may process "tokens" values via a plain FOR command:
   for %%a in (%tokens%) do echo Token via FOR: %%a

   Rem/For    ... or via another FOR /F command:
   for /F "tokens=1-%tokens.len%" %%a in ("%tokens%") do (
      echo Token #1 of FOR /F: %%a
      echo Token #6 of FOR /F: %%f
      echo Token #9 of FOR /F: %%i
   )

   Rem/For    You may also directly use the auxiliary "$#" tokens variables. See description below.
   echo Token #242 via its token variable: %%%$242%
   echo Full path of token #273: %%~F%$273%

   Rem/For    If there are additional tokens after the $numTokens number used to create this file,
   Rem/For    they will be grouped into the next token. For example, if this file was created via
   Rem/For    MakeForTokens.bat 300, then you may show the tokens beyond 300 this way:
   echo Additional tokens after the #300: %%%$301%

Rem/For  Closing parenthesis of the main FOR /F command
)

goto :EOF

Support subroutines. You must not modify any code below this line,
but all these explanations may be removed.

The next subroutine define the auxiliary variables that are used to access FOR /F tokens.

These variables are *called* $1, $2, etc., so %$43% is *the token* number 43, and %%%$43% is
*the value* of such a token when this construct is placed inside the FOR /F command.
The usual FOR modifiers may be used: %%~NX%$1284% expands to name and extension of token 1284.

The method to create these variables was originally written by DosTips.com user dbenham. See:
http://www.dostips.com/forum/viewtopic.php?f=3&t=7703&p=51595#p51595

This subroutine does not use SETLOCAL. It modify and delete these variables: _cp, _hex, _pages
and use the value of $numTokens variable as input.

:DefineForTokens

for /F "tokens=2 delims=:." %%p in ('chcp') do set /A "_cp=%%p, _pages=($numTokens/256+1)*2"
set "_hex= 0 1 2 3 4 5 6 7 8 9 A B C D E F"
call set "_pages=%%_hex:~0,%_pages%%%"
if %$numTokens% gtr 2048 echo Creating FOR tokens variables, please wait . . .
(
   echo FF FE
   for %%P in (%_pages%) do for %%A in (%_hex%) do for %%B in (%_hex%) do echo %%A%%B 3%%P 0D 00 0A 00
) > "%temp%\forTokens.hex.txt"
certutil.exe -decodehex -f "%temp%\forTokens.hex.txt" "%temp%\forTokens.utf-16le.bom.txt" >NUL
chcp 65001 >NUL
type "%temp%\forTokens.utf-16le.bom.txt" > "%temp%\forTokens.utf8.txt"
(for /L %%N in (0,1,%$numTokens%) do set /P "$%%N=")  < "%temp%\forTokens.utf8.txt" 
chcp %_cp% >NUL
del "%temp%\forTokens.*.txt"
for %%v in (_cp _hex _pages) do set "%%v="
exit /B

The next subroutine create the series of nested FOR's that covers all required FOR tokens;
it use the value of $numTokens variable as input.

:CreateNestedFors

setlocal EnableDelayedExpansion
set /A "numTokens=$numTokens-1, mod=numTokens%%31, i=numTokens/31, lim=31"
if %mod% equ 0 set "mod=31"
set "NestedFors="
for /L %%i in (32,31,%numTokens%) do (
   if !i! equ 1 set "lim=!mod!"
   set "NestedFors=!NestedFors! for /F "tokens=1-!lim!* %delims%" %%!$%%i! in ("%%!$%%i!") do"
   set /A "i-=1"
)
for /F "delims=" %%a in ("!NestedFors!") do endlocal & set "NestedFors=%%a"
exit /B

The next subroutine expands a tokens definition string into a series of individual $# tokens variables.

The tokens definition string have the same form of the standard FOR /F "tokens=x,y,m-n" one.
Additionally, you may define a tokens range in descending order: "tokens=10-6" produce 10 9 8 7 6
or use an increment different than 1: "tokens=10-25+5,400-200-100" produce 10 15 20 25 400 300 200
When the subroutine ends, the total number of tokens created is stored in a global variable
with the same name of the tokens one, plus ".len" added at end.

:ExpandTokensString variable=tokens definitions ...

setlocal EnableDelayedExpansion
set "var=" & set "tokens=" & set "len=0"
if "%~2" equ "" (set "params=%~1") else set "params=%*"
for %%a in (!params!) do (
   if not defined var (
      set "var=%%a"
   ) else for /F "tokens=1-3 delims=-+" %%i in ("%%a") do (
      if "%%j" equ "" (
         if %%i lss %$numTokens% set "tokens=!tokens! %%!$%%i!" & set /A len+=1
      ) else (
         if "%%k" equ "" (set "k=1") else set "k=%%k"
         if %%i leq %%j (
            for /L %%n in (%%i,!k!,%%j) do if %%n lss %$numTokens% set "tokens=!tokens! %%!$%%n!" & set /A len+=1
         ) else (
            for /L %%n in (%%i,-!k!,%%j) do if %%n lss %$numTokens% set "tokens=!tokens! %%!$%%n!" & set /A len+=1
         )
      )
   )
)
endlocal & set "%var%=%tokens%" & set "%var%.len=%len%"
exit /B
